package ink.wgink.module.file.service.filedownload.impl;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import ink.wgink.common.base.DefaultBaseService;
import ink.wgink.module.file.dao.filedownload.IFileDownloadDao;
import ink.wgink.module.file.pojo.dtos.filedownload.FileDownloadDTO;
import ink.wgink.module.file.pojo.vos.filedownload.FileDownloadVO;
import ink.wgink.module.file.service.filedownload.IFileDownloadService;
import ink.wgink.pojo.ListPage;
import ink.wgink.pojo.result.SuccessResultList;
import ink.wgink.util.UUIDUtil;
import ink.wgink.util.date.DateUtil;
import ink.wgink.util.map.HashMapUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.Map;

/**
 * @ClassName: FileDownloadServiceImpl
 * @Description: 文件下载
 * @Author: wanggeng
 * @Date: 2022/8/2 09:58
 * @Version: 1.0
 */
@Service
public class FileDownloadServiceImpl extends DefaultBaseService implements IFileDownloadService {

    @Autowired
    private IFileDownloadDao fileDownloadDao;

    @Override
    public void save(FileDownloadVO fileDownloadVO) {
        Map<String, Object> params = HashMapUtil.beanToMap(fileDownloadVO);
        params.put("fileDownloadId", UUIDUtil.getUUID());
        params.put("gmtCreate", DateUtil.getTime());
        fileDownloadDao.save(params);
    }

    @Override
    public List<FileDownloadDTO> list(Map<String, Object> params) {
        params = params == null ? getHashMap(0) : params;
        return fileDownloadDao.list(params);
    }

    @Override
    public List<FileDownloadDTO> listByFileId(String fileId) {
        Map<String, Object> params = getHashMap(2);
        params.put("fileId", fileId);
        return list(params);
    }

    @Override
    public SuccessResultList<List<FileDownloadDTO>> listPage(ListPage page) {
        PageHelper.startPage(page.getPage(), page.getRows());
        List<FileDownloadDTO> fileDownloadDTOS = list(page.getParams());
        PageInfo<FileDownloadDTO> pageInfo = new PageInfo<>(fileDownloadDTOS);
        return new SuccessResultList<>(fileDownloadDTOS, pageInfo.getPageNum(), pageInfo.getTotal());
    }

    @Override
    public SuccessResultList<List<FileDownloadDTO>> listPageByFileId(String fileId, ListPage page) {
        page.getParams().put("fileId", fileId);
        return listPage(page);
    }

    @Override
    public Integer countByFileId(String fileId) {
        Map<String, Object> params = getHashMap(2);
        params.put("fileId", fileId);
        return fileDownloadDao.count(params);
    }


}
