package ink.wgink.module.file.service.v2.impl;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import ink.wgink.common.base.DefaultBaseService;
import ink.wgink.exceptions.FileException;
import ink.wgink.exceptions.SearchException;
import ink.wgink.module.file.components.FileComponent;
import ink.wgink.module.file.dao.IFileDao;
import ink.wgink.module.file.enums.UploadTypeEnum;
import ink.wgink.module.file.manager.FilesManager;
import ink.wgink.module.file.pojo.dtos.FileInfoDTO;
import ink.wgink.module.file.pojo.dtos.v2.FileUploadSuccessDTO;
import ink.wgink.module.file.pojo.vos.filedownload.FileDownloadVO;
import ink.wgink.module.file.pojo.vos.v2.FileSaveVO;
import ink.wgink.module.file.pojo.vos.v2.FileUpdateVO;
import ink.wgink.module.file.service.filedownload.IFileDownloadService;
import ink.wgink.module.file.service.v2.IFileService;
import ink.wgink.pojo.ListPage;
import ink.wgink.pojo.pos.FilePO;
import ink.wgink.pojo.result.SuccessResultList;
import ink.wgink.util.UUIDUtil;
import ink.wgink.util.date.DateUtil;
import ink.wgink.util.request.RequestUtil;
import ink.wgink.util.thread.CachedThreadPoolUtil;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.File;
import java.io.IOException;
import java.io.InputStream;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.util.Map;

/**
 * @ClassName: FileV2ServiceImpl
 * @Description: 文件V2
 * @Author: wanggeng
 * @Date: 2022/4/13 16:15
 * @Version: 1.0
 */
@Service("fileServiceV2")
public class FileServiceImpl extends DefaultBaseService implements IFileService {

    @Autowired
    private FileComponent fileComponent;
    @Autowired
    private IFileDao fileDao;
    @Autowired
    private IFileDownloadService fileDownloadService;

    @Override
    public FileUploadSuccessDTO uploadSingle(MultipartFile uploadFile, UploadTypeEnum uploadTypeEnum) {
        FileSaveVO fileSaveVO = getFileSaveVO(uploadFile, uploadTypeEnum);
        fileSaveVO.setCreator(securityComponent.getCurrentUser().getUserId());
        return saveFile(fileSaveVO);
    }

    @Override
    public FileUploadSuccessDTO uploadSingle(InputStream inputStream, UploadTypeEnum uploadTypeEnum, String fileName) {
        FileSaveVO fileSaveVO = getFileSaveVO(inputStream, uploadTypeEnum, fileName);
        fileSaveVO.setCreator(securityComponent.getCurrentUser().getUserId());
        return saveFile(fileSaveVO);
    }


    @Override
    public FileUploadSuccessDTO uploadSingleByToken(String token, MultipartFile uploadFile, UploadTypeEnum uploadTypeEnum) {
        FileSaveVO fileSaveVO = getFileSaveVO(uploadFile, uploadTypeEnum);
        fileSaveVO.setCreator(getAppTokenUser(token).getId());
        return saveFile(fileSaveVO);
    }

    @Override
    public FileUploadSuccessDTO uploadSingleByToken(String token, InputStream inputStream, UploadTypeEnum uploadTypeEnum, String fileName) {
        FileSaveVO fileSaveVO = getFileSaveVO(inputStream, uploadTypeEnum, fileName);
        fileSaveVO.setCreator(getAppTokenUser(token).getId());
        return saveFile(fileSaveVO);
    }

    @Override
    public FileUploadSuccessDTO uploadSingleByUserId(String userId, MultipartFile uploadFile, UploadTypeEnum uploadTypeEnum) {
        FileSaveVO fileSaveVO = getFileSaveVO(uploadFile, uploadTypeEnum);
        fileSaveVO.setCreator(userId);
        return saveFile(fileSaveVO);
    }

    @Override
    public FileUploadSuccessDTO uploadSingleByUserId(String userId, InputStream inputStream, UploadTypeEnum uploadTypeEnum, String fileName) {
        FileSaveVO fileSaveVO = getFileSaveVO(inputStream, uploadTypeEnum, fileName);
        fileSaveVO.setCreator(userId);
        return saveFile(fileSaveVO);
    }

    @Override
    public FileUploadSuccessDTO saveFile(FileSaveVO fileSaveVO) {
        String fileUrl = fileComponent.getFileUrl(fileSaveVO.getUploadPath());
        String fileId = UUIDUtil.getUUID();
        Map<String, Object> params = getHashMap(10);
        params.put("fileId", fileId);
        params.put("fileName", fileSaveVO.getFileName());
        params.put("filePath", fileSaveVO.getUploadPath());
        params.put("fileUrl", fileUrl);
        params.put("fileType", fileSaveVO.getFileType());
        params.put("fileSize", fileSaveVO.getFileSize());
        params.put("isBack", 0);

        String time = DateUtil.getTime();
        params.put("creator", fileSaveVO.getCreator());
        params.put("modifier", fileSaveVO.getCreator());
        params.put("gmtCreate", time);
        params.put("gmtModified", time);
        params.put("isDelete", 0);
        fileDao.save(params);

        return new FileUploadSuccessDTO(fileId, fileSaveVO.getFileName(), fileSaveVO.getFileSize(), fileUrl);
    }

    @Override
    public void update(FileUpdateVO fileUpdateVO) {
        Map<String, Object> params = getHashMap(10);
        params.put("fileId", fileUpdateVO.getFileId());
        params.put("fileName", fileUpdateVO.getFileName());
        params.put("filePath", fileUpdateVO.getUploadPath());
        params.put("fileUrl", fileComponent.getFileUrl(fileUpdateVO.getUploadPath()));
        params.put("fileType", fileUpdateVO.getFileType());
        params.put("fileSize", fileUpdateVO.getFileSize());
        params.put("modifier", fileUpdateVO.getCreator());
        params.put("gmtModified", DateUtil.getTime());
        fileDao.update(params);
    }

    @Override
    public void delete(List<String> fileIds) {
        if (fileIds.isEmpty()) {
            return;
        }
        Map<String, Object> params = getHashMap(2);
        params.put("fileIds", fileIds);
        List<FilePO> filePOS = fileDao.listPO(params);
        // 删除源文件
        filePOS.forEach(filePO -> {
            File file = new File(filePO.getFilePath());
            if (!file.exists()) {
                return;
            }
            file.delete();
        });
        // 删除记录
        fileDao.delete(params);
    }

    @Override
    public FilePO getPO(Map<String, Object> params) {
        return fileDao.getPO(params);
    }

    @Override
    public FilePO getPO(String fileId) {
        Map<String, Object> params = getHashMap(2);
        params.put("fileId", fileId);
        return getPO(params);
    }

    @Override
    public void download(HttpServletRequest request, HttpServletResponse response, boolean isOpen, String fileId) {
        FilePO filePO = getPO(fileId);
        if (filePO == null) {
            throw new FileException("查询失败");
        }
        File file = new File(filePO.getFilePath());
        if (!file.exists()) {
            throw new FileException("文件不存在");
        }
        try {
            String requestIp = RequestUtil.getRequestIp(request);
            String code = FilesManager.getInstance().generateCode(fileId, filePO.getFileName());
            response.sendRedirect(String.format("%s/%s?file=%s&code=%s&open=%d", request.getContextPath(), filePO.getFileUrl(), fileId, code, isOpen ? 1 : 0));
            if (!isOpen && !StringUtils.isBlank(requestIp)) {
                // 记录下载历史
                CachedThreadPoolUtil.execute(() -> {
                    FileDownloadVO fileDownloadVO = new FileDownloadVO(filePO.getFileId(), requestIp);
                    fileDownloadService.save(fileDownloadVO);
                });
            }
        } catch (IOException e) {
            throw new RuntimeException(e);
        }
    }

    @Override
    public List<FileInfoDTO> list(Map<String, Object> params) {
        params = params == null ? getHashMap(0) : params;
        setQueryFileType(params);
        List<FileInfoDTO> fileInfoDTOs = fileDao.listInfo(params);
        setDownloadCount(fileInfoDTOs);
        return fileInfoDTOs;
    }

    @Override
    public SuccessResultList<List<FileInfoDTO>> listPage(ListPage page) {
        PageHelper.startPage(page.getPage(), page.getRows());
        List<FileInfoDTO> fileInfoDTOs = list(page.getParams());
        setDownloadCount(fileInfoDTOs);
        PageInfo<FileInfoDTO> pageInfo = new PageInfo<>(fileInfoDTOs);
        return new SuccessResultList<>(fileInfoDTOs, pageInfo.getPageNum(), pageInfo.getTotal());
    }

    /**
     * 设置查询文件类型
     *
     * @param params
     */
    private void setQueryFileType(Map<String, Object> params) {
        String fileType = (String) params.get("fileType");
        if (StringUtils.isBlank(fileType)) {
            return;
        }
        List<String> fileTypes;
        if (StringUtils.equals("image", fileType)) {
            fileTypes = Arrays.asList(fileComponent.getImageTypes());
        } else if (StringUtils.equals("video", fileType)) {
            fileTypes = Arrays.asList(fileComponent.getVideoTypes());
        } else if (StringUtils.equals("audio", fileType)) {
            fileTypes = Arrays.asList(fileComponent.getAudioTypes());
        } else if (StringUtils.equals("file", fileType)) {
            fileTypes = Arrays.asList(fileComponent.getFileTypes());
        } else {
            fileTypes = new ArrayList<>();
        }
        params.put("fileTypes", fileTypes);
    }

    /**
     * 设置下载次数
     *
     * @param fileInfoDTOs
     */
    private void setDownloadCount(List<FileInfoDTO> fileInfoDTOs) {
        fileInfoDTOs.forEach(fileInfoDTO -> {
            Integer downloadCount = fileDownloadService.countByFileId(fileInfoDTO.getFileId());
            fileInfoDTO.setDownloadCount(downloadCount);
        });
    }

    /**
     * 获取文件保存VO
     *
     * @param uploadFile
     * @param uploadTypeEnum
     * @return
     */
    private FileSaveVO getFileSaveVO(MultipartFile uploadFile, UploadTypeEnum uploadTypeEnum) {
        String fileName = uploadFile.getOriginalFilename();
        InputStream inputStream;
        try {
            inputStream = uploadFile.getInputStream();
        } catch (IOException e) {
            throw new SearchException(e);
        }
        return getFileSaveVO(inputStream, uploadTypeEnum, fileName);
    }

    /**
     * 获取文件保存VO
     *
     * @param inputStream
     * @param uploadTypeEnum
     * @param fileName
     * @return
     */
    private FileSaveVO getFileSaveVO(InputStream inputStream, UploadTypeEnum uploadTypeEnum, String fileName) {
        String fileType = fileComponent.getFileType(fileName);
        String uploadPath = fileComponent.getUploadPath(uploadTypeEnum, fileType);
        String uuidFileName = UUIDUtil.get32UUID() + "." + fileType;
        long fileSize = fileComponent.saveFile(inputStream, uuidFileName, uploadPath);
        // 保存文件
        FileSaveVO fileSaveVO = new FileSaveVO();
        fileSaveVO.setFileName(fileName);
        fileSaveVO.setFileType(fileType);
        fileSaveVO.setUploadPath(uploadPath + File.separator + uuidFileName);
        fileSaveVO.setFileSize(fileSize);
        return fileSaveVO;
    }

}
